@@ -8,6 +8,7 @@
 #else
 
 #define RTLD_LAZY 0
+#define RTLD_GLOBAL 1
 #define _FAKE_DLFCN_HDL (void *)0xbeefcafe
 
 static inline void *dlopen(const char *file, int flag)
@@ -18,7 +19,7 @@ static inline void *dlopen(const char *file, int flag)
 		return NULL;
 }
 
-extern void *_dlsym(const char *sym);
+void *_dlsym(const char *sym);
 static inline void *dlsym(void *handle, const char *sym)
 {
 	if (handle != _FAKE_DLFCN_HDL)
